@@ -177,6 +177,11 @@ def numeric_only(value:str,negatives=True)->bool:
         `method_name`: numeric_only
         * @xxx [01-06-2023 09:49:15]: documentation for numeric_only
     '''
+    if isinstance(value,(str)):
+        value = _csu.strip(value,[" "])
+        if len(value) == 0:
+            return False
+
     if is_integer(value,negatives):
         return True
     if is_float(value,negatives):
